@@ -1,3 +1,5 @@
+skip_if_not_installed("mlr3")
+
 set.seed(42)
 task = mlr3::tsk("sonar")
 learner = mlr3::lrn("classif.rpart", predict_type = "prob")
@@ -16,19 +18,19 @@ test_that("autoplot ResampleResult", {
   set.seed(42)
   p = autoplot(rr, measure = msr("classif.ce"), type = "boxplot")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("resampleresult_boxplot", p)
+  expect_doppelganger("resampleresult_boxplot", p)
 
   p = autoplot(rr, measure = msr("classif.ce"), type = "histogram")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("resampleresult_histogram", p)
+  expect_doppelganger("resampleresult_histogram", p)
 
   p = autoplot(rr, type = "roc")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("resampleresult_roc", p)
+  expect_doppelganger("resampleresult_roc", p)
 
   p = autoplot(rr, type = "prc")
   expect_true(is.ggplot(p))
-  vdiffr::expect_doppelganger("resampleresult_prc", p)
+  expect_doppelganger("resampleresult_prc", p)
 })
 
 test_that("autoplot ResampleResult type=prediction", {
